CREATE TABLE TAFATIPUSOK ( 
    FAZONOSITO INTEGER           PRIMARY KEY AUTOINCREMENT
                                 NOT NULL,
    FNEV       VARCHAR( 70 )     UNIQUE
                                 NOT NULL,
    FAFA       DECIMAL( 10, 2 )  DEFAULT NULL,
    FIDO       TIMESTAMP         DEFAULT ( CURRENT_TIME ),
    FUSER      VARCHAR( 70 ) 
);
INSERT INTO TAFATIPUSOK VALUES ( 
    1,
    '27%-os ÁFA',
    '27.00',
    CURRENT_TIME,
    NULL 
);

CREATE TABLE TANYAGMOZGAS ( 
    FAZONOSITO     INTEGER         PRIMARY KEY AUTOINCREMENT
                                     NOT NULL,
    FDATUM         TIMESTAMP         NOT NULL
                                     DEFAULT ( CURRENT_TIME ),
    FMOZGASKOD     INTEGER         NOT NULL,
    FANYAGKOD      VARCHAR( 70 )     NOT NULL,
    FANYAGNEV      VARCHAR( 100 )    DEFAULT NULL,
    FNETTOAR       DECIMAL( 10, 2 )  NOT NULL,
    FEGYSEG        VARCHAR( 20 )     DEFAULT NULL,
    FMENNYISEG     DECIMAL( 10, 2 )  NOT NULL,
    FKTGH_ROL      VARCHAR( 100 )    DEFAULT NULL,
    FKTGH_RE       VARCHAR( 100 )    DEFAULT NULL,
    FCEG           INTEGER         DEFAULT NULL,
    FBIZONYLATSZAM VARCHAR( 70 )     DEFAULT NULL,
    FUSER          VARCHAR( 70 )     DEFAULT NULL,
    FELOZMENY      INTEGER         NOT NULL,
    FKONYVELVE     INTEGER         NOT NULL,
    FIDO           TIMESTAMP         NOT NULL
                                     DEFAULT ( CURRENT_TIME ),
    FFIFO          DECIMAL( 10, 2 )  DEFAULT NULL,
    CONSTRAINT ANYAGMOZGAS_ANYAGKOD FOREIGN KEY ( FANYAGKOD ) REFERENCES TTORZS ( FRAKTKOD ) ON DELETE RESTRICT ON UPDATE CASCADE,
    CONSTRAINT ANYAGMOZGAS_MOZGASKOD FOREIGN KEY ( FMOZGASKOD ) REFERENCES TMOZGASTIPUSOK ( FKOD ) ON DELETE RESTRICT ON UPDATE CASCADE 
);
CREATE INDEX idx_ANYAGKOD ON TANYAGMOZGAS ( 
    FANYAGKOD 
);
CREATE INDEX idx_DATUM ON TANYAGMOZGAS ( 
    FDATUM 
);
CREATE INDEX idx_MOZGASKOD ON TANYAGMOZGAS ( 
    FMOZGASKOD 
);
CREATE INDEX idx_KTGH_ROL ON TANYAGMOZGAS ( 
    FKTGH_ROL 
);
CREATE INDEX idx_KTGH_RE ON TANYAGMOZGAS ( 
    FKTGH_RE 
);
CREATE INDEX idx_CEG ON TANYAGMOZGAS ( 
    FCEG 
);

CREATE TABLE TAUTOBIZONYLAT ( 
    FAZONOSITO       INTEGER        PRIMARY KEY AUTOINCREMENT
                                    NOT NULL,
    FSZLAVEVO        INTEGER        NOT NULL,
    FSZLAMINTA       INTEGER        NOT NULL,
    FSZLARENDSZAM    VARCHAR( 70 )  DEFAULT NULL,
    FSZLAMEGRENDELES VARCHAR( 70 )  DEFAULT NULL,
    FSZLAHIVATKOZAS  VARCHAR( 70 )  DEFAULT NULL,
    FSZLAGYAKORISAG  INTEGER        NOT NULL,
    FSZLAGENNEXT     TIMESTAMP      NOT NULL
                                    DEFAULT CURRENT_TIME,
    FIDO             TIMESTAMP      DEFAULT CURRENT_TIME
                                    NOT NULL,
    FUSER            VARCHAR( 70 )  DEFAULT NULL,
    CONSTRAINT AUTOBIZONYLAT_MINTA FOREIGN KEY ( FSZLAMINTA ) REFERENCES TBIZONYLATFEJ ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE,
    CONSTRAINT AUTOBIZONYLAT_VEVO FOREIGN KEY ( FSZLAVEVO ) REFERENCES TPARTNEREK ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE 
);
CREATE UNIQUE INDEX idx_AUTOBIZONYLAT_ID ON TAUTOBIZONYLAT ( 
    FSZLAVEVO,
    FSZLAMINTA 
);
CREATE INDEX idx_AUTOBIZONYLAT_MINTA ON TAUTOBIZONYLAT ( 
    FSZLAMINTA 
);

CREATE TABLE TBEALLIT ( 
    FCEGNEV            VARCHAR( 100 )    DEFAULT NULL,
    FCEGORSZAG         VARCHAR( 100 )    DEFAULT NULL,
    FCEGIRSZ           VARCHAR( 70 )     DEFAULT NULL,
    FCEGTELEP          VARCHAR( 100 )    DEFAULT NULL,
    FCEGUTCA           VARCHAR( 100 )    DEFAULT NULL,
    FCEGTEL            VARCHAR( 70 )     DEFAULT NULL,
    FCEGFAX            VARCHAR( 70 )     DEFAULT NULL,
    FCEGEMAIL          VARCHAR( 100 )    DEFAULT NULL,
    FCEGBANKSZLA       VARCHAR( 100 )    DEFAULT NULL,
    FCEGDEVIZASZLA1    VARCHAR( 100 )    DEFAULT NULL,
    FCEGDEVIZASZLA2    VARCHAR( 100 )    DEFAULT NULL,
    FCEGDEVIZASZLA3    VARCHAR( 100 )    DEFAULT NULL,
    FCEGADOSZAM        VARCHAR( 100 )    DEFAULT NULL,
    FCEGADOSZAMEU      VARCHAR( 100 )    DEFAULT NULL,
    FCEGVALLIGSZAM     VARCHAR( 100 )    DEFAULT NULL,
    FDEFRAKTAR         INTEGER           DEFAULT NULL,
    FDEFKTGH           INTEGER           DEFAULT NULL,
    FDEFFIZHATARIDO    INTEGER           DEFAULT NULL,
    FDEFFIZMOD         VARCHAR( 70 )     DEFAULT NULL,
    FDEFSZAMLAMEGJEGYZ VARCHAR( 255 )    DEFAULT NULL,
    FDEFVALUTAFORMAT   VARCHAR( 10 )     DEFAULT NULL,
    FDEFARRES          DECIMAL( 10, 2 )  DEFAULT NULL,
    FIDO               TIMESTAMP         NOT NULL
                                         DEFAULT CURRENT_TIMESTAMP,
    FUSER              VARCHAR( 70 )     DEFAULT NULL,
    FSZLAEMBLEMA       LONGBLOB,
    FSZLAPELDANY       INTEGER           DEFAULT NULL 
);

CREATE TABLE TBIZONYLATFEJ ( 
    FAZONOSITO        INTEGER           PRIMARY KEY AUTOINCREMENT
                                        NOT NULL,
    FBIZTIP           INTEGER           NOT NULL,
    FSTATUS           INTEGER           NOT NULL,
    FCEGNEV           VARCHAR( 100 )    NOT NULL,
    FCEGORSZAG        VARCHAR( 100 )    DEFAULT NULL,
    FCEGIRSZ          VARCHAR( 70 )     DEFAULT NULL,
    FCEGTELEP         VARCHAR( 100 )    NOT NULL,
    FCEGUTCA          VARCHAR( 100 )    NOT NULL,
    FCEGTEL           VARCHAR( 70 )     DEFAULT NULL,
    FCEGFAX           VARCHAR( 70 )     DEFAULT NULL,
    FCEGEMAIL         VARCHAR( 100 )    DEFAULT NULL,
    FCEGBANKSZLA      VARCHAR( 100 )    DEFAULT NULL,
    FCEGADOSZAM       VARCHAR( 100 )    DEFAULT NULL,
    FCEGADOSZAMEU     VARCHAR( 100 )    DEFAULT NULL,
    FCEGVALLIGSZAM    VARCHAR( 100 )    DEFAULT NULL,
	
	FVEVOAZONOSITO    INTEGER           DEFAULT NULL,
    FVEVONEV          VARCHAR( 100 )    NOT NULL,
    FVEVOORSZAG       VARCHAR( 100 )    DEFAULT NULL,
    FVEVOIRSZ         VARCHAR( 70 )     DEFAULT NULL,
    FVEVOTELEPULES    VARCHAR( 100 )    NOT NULL,
    FVEVOUTCA         VARCHAR( 100 )    NOT NULL,
    FVEVOTELEFON      VARCHAR( 100 )    DEFAULT NULL,
    FVEVOFAX          VARCHAR( 100 )    DEFAULT NULL,
    FVEVOEMAIL        VARCHAR( 100 )    DEFAULT NULL,
    FVEVOBANKSZLA     VARCHAR( 100 )    DEFAULT NULL,
    FVEVOADOSZAM      VARCHAR( 100 )    DEFAULT NULL,
    FFORMATUM         INTEGER           NOT NULL,
    FSZEV             INTEGER           NOT NULL,
    FSZSZAM           INTEGER           NOT NULL,
    FKIALLDATUM       TIMESTAMP         NOT NULL
                                        DEFAULT CURRENT_TIMESTAMP,
    FFIZDATUM         TIMESTAMP         NOT NULL
                                        DEFAULT CURRENT_TIME,
    FTELJDATUM        TIMESTAMP         NOT NULL
                                        DEFAULT CURRENT_TIME,
    FFIZMOD           VARCHAR( 70 )     DEFAULT NULL,
    FTIPUS            INTEGER           DEFAULT NULL,
    FKEDVEZMENY       DECIMAL( 10, 2 )  DEFAULT NULL,
    FIDO              TIMESTAMP         NOT NULL
                                        DEFAULT CURRENT_TIME,
    FUSER             VARCHAR( 70 )     DEFAULT NULL,
    FMEGJEGYZES       VARCHAR( 255 )    DEFAULT NULL,
    FRENDSZAM         VARCHAR( 70 )     DEFAULT NULL,
    FMEGRENDELES      VARCHAR( 70 )     DEFAULT NULL,
    FHIVATKOZAS       VARCHAR( 70 )     DEFAULT NULL,
    FNYOMTATVA        INTEGER           DEFAULT NULL,
    FPELDANY          INTEGER           DEFAULT NULL,
    FVALUTA           VARCHAR( 10 )     DEFAULT NULL,
    FSTORNOSZLA       INTEGER           DEFAULT NULL,
    FSTORNOKIALLDATUM TIMESTAMP,
    FSTR01            VARCHAR( 100 )    DEFAULT NULL,
    FSTR02            VARCHAR( 100 )    DEFAULT NULL,
    FSTR03            VARCHAR( 100 )    DEFAULT NULL,
    FSTR04            VARCHAR( 100 )    DEFAULT NULL,
    FSTR05            VARCHAR( 100 )    DEFAULT NULL,
    FSTR06            VARCHAR( 100 )    DEFAULT NULL,
    FSTR07            VARCHAR( 100 )    DEFAULT NULL,
    FSTR08            VARCHAR( 100 )    DEFAULT NULL,
    FSTR09            VARCHAR( 100 )    DEFAULT NULL,
    FSTR10            VARCHAR( 100 )    DEFAULT NULL 
);

CREATE UNIQUE INDEX idx_BIZONYLATFEJ_KOD ON TBIZONYLATFEJ ( 
    FBIZTIP,
    FSZEV,
    FSZSZAM 
);

CREATE TABLE TBIZONYLATTETEL ( 
    FAZONOSITO    INTEGER           PRIMARY KEY AUTOINCREMENT
                                    NOT NULL,
    FBIZONYLATFEJ INTEGER           NOT NULL,
    FTETELKOD     VARCHAR( 70 )     NOT NULL,
    FITJSZ        VARCHAR( 70 )     DEFAULT NULL,
    FNEV          VARCHAR( 100 )    DEFAULT NULL,
    FMENNY        DECIMAL( 10, 2 )  DEFAULT NULL,
    FEGYSEG       VARCHAR( 20 )     DEFAULT NULL,
    FEGYSEGAR     DECIMAL( 10, 2 )  DEFAULT NULL,
    FAFA          DECIMAL( 10, 2 )  DEFAULT NULL,
    FKEDVEZMENY   DECIMAL( 10, 2 )  DEFAULT NULL,
    FIDO          TIMESTAMP         NOT NULL
                                    DEFAULT CURRENT_TIMESTAMP,
    FUSER         VARCHAR( 70 )     DEFAULT NULL,
    FANYAGMOZGAS  INTEGER           DEFAULT NULL,
    FVISSZAVET    DECIMAL( 10, 2 )  DEFAULT NULL,
    FAFAAZON      INTEGER           DEFAULT NULL,
    FAFANEV       VARCHAR( 30 )     DEFAULT NULL,
    CONSTRAINT BIZTETEL_BIZONYLATFEJ FOREIGN KEY ( FBIZONYLATFEJ ) REFERENCES TBIZONYLATFEJ ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE 
);
CREATE INDEX idx_BIZTETEL_BIZONYLATFEJ ON TBIZONYLATTETEL ( 
    FBIZONYLATFEJ 
);

CREATE TABLE TBIZTETELMEGJEGYZ ( 
    FAZONOSITO      INTEGER         PRIMARY KEY AUTOINCREMENT
                                    NOT NULL,
    FBIZONYLATTETEL INTEGER         NOT NULL,
    FSOR            VARCHAR( 255 )  DEFAULT NULL,
    FIDO            TIMESTAMP       NOT NULL
                                    DEFAULT CURRENT_TIME,
    FUSER           VARCHAR( 70 )   DEFAULT NULL,
    CONSTRAINT BIZTETELMEGJEGY_BIZONYLATTETEL FOREIGN KEY ( FBIZONYLATTETEL ) REFERENCES TBIZONYLATTETEL ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE 
);
CREATE INDEX idx_BIZTETELMEGJEGY_BIZONYLATTETEL ON TBIZTETELMEGJEGYZ ( 
    FBIZONYLATTETEL 
);

CREATE TABLE TCSOPORTOK ( 
    FAZONOSITO INTEGER         PRIMARY KEY AUTOINCREMENT
                               NOT NULL,
    FNEV       VARCHAR( 70 )   NOT NULL,
    FLEIRAS    VARCHAR( 255 )  DEFAULT NULL,
    FFUNKCIO   INTEGER         DEFAULT NULL,
    FIDO       TIMESTAMP       NOT NULL
                               DEFAULT CURRENT_TIME,
    FUSER      VARCHAR( 70 )   DEFAULT NULL 
);
CREATE UNIQUE INDEX idx_CSOPORTOK_NEV ON TCSOPORTOK ( 
    FNEV 
);
INSERT INTO TCSOPORTOK VALUES ( 
    1,
    'Alap. csoport',
    'Alapértelmezett csoport',
    0,
    CURRENT_TIME,
    NULL 
);

CREATE TABLE TFIZMOD ( 
    FAZONOSITO  INTEGER        PRIMARY KEY AUTOINCREMENT
                               NOT NULL,
    FNEV        VARCHAR( 70 )  NOT NULL,
    FIDO        TIMESTAMP      NOT NULL
                               DEFAULT CURRENT_TIME,
    FUSER       VARCHAR( 70 )  DEFAULT NULL,
    FFIZHAT     INTEGER        DEFAULT NULL,
    FSZLAFORMAT INTEGER        DEFAULT NULL 
);
CREATE UNIQUE INDEX idx_FIZMOD_NEV ON TFIZMOD ( 
    FNEV 
);
INSERT INTO TFIZMOD VALUES ( 
    1,
    'Készpénz',
    CURRENT_TIME,
    'default',
    0,
    1004 
);
INSERT INTO TFIZMOD VALUES ( 
    2,
    'Átutalás',
    CURRENT_TIME,
    'default',
    14,
    1003 
);

CREATE TABLE TKESZLET ( 
    FKTGH      VARCHAR( 100 )    NOT NULL,
    FANYAGKOD  VARCHAR( 70 )     NOT NULL,
    FMENNYISEG DECIMAL( 10, 2 )  DEFAULT NULL,
    FERTEK     DECIMAL( 10, 2 )  DEFAULT NULL,
    FIDO       TIMESTAMP         NOT NULL
                                 DEFAULT CURRENT_TIMESTAMP,
    FUSER      VARCHAR( 70 )     DEFAULT NULL,
    PRIMARY KEY ( FKTGH, FANYAGKOD ) 
);

CREATE TABLE TKOLTSEGHELYEK ( 
    FAZONOSITO INTEGER         PRIMARY KEY AUTOINCREMENT
                               NOT NULL,
    FNEV       VARCHAR( 100 )  NOT NULL,
    FTIPUS     INTEGER         NOT NULL,
    FIDO       TIMESTAMP       NOT NULL
                               DEFAULT CURRENT_TIME,
    FUSER      VARCHAR( 70 )   DEFAULT NULL 
);
CREATE UNIQUE INDEX idx_KOLTSEGHELYEK_NEV ON TKOLTSEGHELYEK ( 
    FNEV 
);
INSERT INTO TKOLTSEGHELYEK VALUES ( 
    1,
    'Raktár',
    1,
    CURRENT_TIME,
    NULL 
);
INSERT INTO TKOLTSEGHELYEK VALUES ( 
    2,
    'Alap. ktgh.',
    0,
    CURRENT_TIME,
    NULL 
);

CREATE TABLE TMEGJEGYZFEJ ( 
    FAZONOSITO INTEGER         PRIMARY KEY AUTOINCREMENT
                               NOT NULL,
    FNEV       VARCHAR( 100 )  NOT NULL,
    FIDO       TIMESTAMP       NOT NULL
                               DEFAULT CURRENT_TIME,
    FUSER      VARCHAR( 70 )   DEFAULT NULL 
);
CREATE UNIQUE INDEX idx_NEV_MEGJEGYZFEJ ON TMEGJEGYZFEJ ( 
    FNEV 
);

CREATE TABLE TMEGJEGYZSOROK ( 
    FAZONOSITO   INTEGER         PRIMARY KEY AUTOINCREMENT
                                 NOT NULL,
    FMEGJEGYZFEJ INTEGER         NOT NULL,
    FSOR         VARCHAR( 255 )  NOT NULL,
    FIDO         TIMESTAMP       NOT NULL
                                 DEFAULT CURRENT_TIME,
    FUSER        VARCHAR( 70 )   DEFAULT NULL,
    CONSTRAINT MEGJEGYZSOROK_MEGJEGYZFEJ FOREIGN KEY ( FMEGJEGYZFEJ ) REFERENCES TMEGJEGYZFEJ ( FAZONOSITO ) ON DELETE CASCADE
                                                                                                                 ON DELETE RESTRICT ON UPDATE CASCADE 
);
CREATE INDEX idx_MEGJEGYZSOROK_MEGJEGYZFEJ ON TMEGJEGYZSOROK ( 
    FMEGJEGYZFEJ 
);

CREATE TABLE TMOZGASTIPUSOK ( 
    FKOD INTEGER        NOT NULL,
    FNEV VARCHAR( 70 )  NOT NULL,
    PRIMARY KEY ( FKOD ) 
);
CREATE UNIQUE INDEX idx_MOZGASTIPUS_NEV ON TMOZGASTIPUSOK ( 
    FNEV 
);
INSERT INTO TMOZGASTIPUSOK VALUES (1,'BEÉRKEZéS RÖGZÍTÉSE');
INSERT INTO TMOZGASTIPUSOK VALUES (2,'ÁTVÉTEL KÉSZLETRE/BEÉRKEZéS KÖNYVELÉSE');
INSERT INTO TMOZGASTIPUSOK VALUES (3,'ÁTHELYEZÉS KÖLTSÉGHELYEK KÖZÖTT');
INSERT INTO TMOZGASTIPUSOK VALUES (4,'KIADÁS MUNKALAPRA');
INSERT INTO TMOZGASTIPUSOK VALUES (5,'VISSZAVÉTELEZÉS MUNKALAPRÓL');
INSERT INTO TMOZGASTIPUSOK VALUES (6,'VISSZÁRU BESZÁLLÍTÓNAK, NAGYKERNEK');
INSERT INTO TMOZGASTIPUSOK VALUES (7,'SELEJTEZÉS RÖGZÍTÉSE');
INSERT INTO TMOZGASTIPUSOK VALUES (8,'LELTÁRTÖBBLET');
INSERT INTO TMOZGASTIPUSOK VALUES (9,'LELTáRHIÁNY');
INSERT INTO TMOZGASTIPUSOK VALUES (10,'NYITÓKÉSZLET/LELTÁRI EREDMÉNY-KORREKCIÓ');
INSERT INTO TMOZGASTIPUSOK VALUES (11,'TÖRLÉS: ÁTVÉTEL KÖLTSÉGHELYRE');
INSERT INTO TMOZGASTIPUSOK VALUES (12,'TÖRLÉS: KIADÁS KÖLTSÉGHELYRŐL');
INSERT INTO TMOZGASTIPUSOK VALUES (13,'VISSZÁRÚ VEVŐTŐL');

CREATE TABLE TPARTNERAUTO ( 
    FAZONOSITO   INTEGER        PRIMARY KEY AUTOINCREMENT
                                NOT NULL,
    FPARTNER     INTEGER        NOT NULL,
    FRENDSZAM    VARCHAR( 70 )  DEFAULT NULL,
    FGYARTASIEV  INTEGER        DEFAULT NULL,
    FGYARTMANY   VARCHAR( 70 )  DEFAULT NULL,
    FTIPUS       VARCHAR( 70 )  DEFAULT NULL,
    FALVAZSZAM   VARCHAR( 70 )  DEFAULT NULL,
    FMOTORSZAM   VARCHAR( 70 )  DEFAULT NULL,
    FVASARLASMOD INTEGER        DEFAULT NULL,
    FVASARLASEVE INTEGER        DEFAULT NULL 
);
CREATE UNIQUE INDEX idx_PARTNERAUTO_RENDSZAM ON TPARTNERAUTO ( 
    FRENDSZAM 
);

CREATE TABLE TPARTNEREK ( 
    FAZONOSITO   INTEGER           PRIMARY KEY AUTOINCREMENT
                                   NOT NULL,
    FNEV         VARCHAR( 100 )    NOT NULL,
    FVEZETEKNEV  VARCHAR( 50 )     DEFAULT NULL,
    FKERESZTNEV  VARCHAR( 50 )     DEFAULT NULL,
    FSZULDATUM   DATE              DEFAULT NULL,
    FNEM         CHAR( 1 )         DEFAULT NULL,
    FTIPUS       INTEGER           DEFAULT NULL,
    FORSZAG      VARCHAR( 100 )    DEFAULT NULL,
    FIRSZ        VARCHAR( 70 )     DEFAULT NULL,
    FTELEPULES   VARCHAR( 100 )    DEFAULT NULL,
    FUTCA        VARCHAR( 100 )    DEFAULT NULL,
    FTELEFON     VARCHAR( 100 )    DEFAULT NULL,
    FFAX         VARCHAR( 100 )    DEFAULT NULL,
    FEMAIL       VARCHAR( 100 )    DEFAULT NULL,
    FBANKSZLA    VARCHAR( 100 )    DEFAULT NULL,
    FADOSZAM     VARCHAR( 100 )    DEFAULT NULL,
    FKARTYASZAM  VARCHAR( 100 )    DEFAULT NULL,
    FKEDVEZMENY  DECIMAL( 10, 2 )  DEFAULT NULL,
    FDEFVALUTA   VARCHAR( 10 )     DEFAULT NULL,
    FDEFFIZHAT   INTEGER           DEFAULT '0',
    FDEFSZLAPELD INTEGER           DEFAULT '0',
    FIDO         TIMESTAMP         NOT NULL
                                   DEFAULT CURRENT_TIME,
    FUSER        VARCHAR( 70 )     DEFAULT NULL 
);
CREATE UNIQUE INDEX idx_PARTNER_NEV ON TPARTNEREK ( 
    FNEV 
);
INSERT INTO TPARTNEREK VALUES ( 
    1,
    'Mindenes',
    '',
    '',
    '1899-12-30',
    '-',
    2,
    'Magyarország',
    '9999',
    '-',
    '-',
    '',
    '',
    '',
    '12345678-12345678',
    '123456789-1-12',
    '',
    '0.00',
    'HUF',
    10,
    2,
    CURRENT_TIME,
    'default' 
);

CREATE TABLE TRAKTGYUJTO ( 
    FGYUJTOKOD VARCHAR( 70 )     NOT NULL,
    FTETELKOD  VARCHAR( 70 )     NOT NULL,
    FMENNYISEG DECIMAL( 10, 2 )  DEFAULT NULL,
    PRIMARY KEY ( FGYUJTOKOD, FTETELKOD ),
    CONSTRAINT RAKTGYUJTO_GYUJTOKOD FOREIGN KEY ( FGYUJTOKOD ) REFERENCES TTORZS ( FRAKTKOD ) ON DELETE RESTRICT ON UPDATE CASCADE,
    CONSTRAINT RAKTGYUJTO_TETELKOD FOREIGN KEY ( FTETELKOD ) REFERENCES TTORZS ( FRAKTKOD ) ON DELETE RESTRICT ON UPDATE CASCADE 
);
CREATE INDEX idx_RAKTGYUJTO_TETELKOD ON TRAKTGYUJTO ( 
    FTETELKOD 
);

CREATE TABLE TRIPORTOK ( 
    FAZONOSITO INTEGER        PRIMARY KEY AUTOINCREMENT
                              NOT NULL,
    FNEV       VARCHAR( 70 )  NOT NULL,
    FTIPUS     INTEGER        NOT NULL,
    FRIPORT    LONGBLOB,
    FIDO       TIMESTAMP      NOT NULL
                              DEFAULT CURRENT_TIME,
    FUSER      VARCHAR( 70 )  DEFAULT NULL 
);
CREATE UNIQUE INDEX idx_RIPORTOK_KOD ON TRIPORTOK ( 
    FTIPUS,
    FNEV 
);

CREATE TABLE TTIPUSOK ( 
    FAZONOSITO INTEGER         PRIMARY KEY AUTOINCREMENT
                               NOT NULL,
    FNEV       VARCHAR( 70 )   NOT NULL,
    FLEIRAS    VARCHAR( 255 )  DEFAULT NULL,
    FCSOPORT   INTEGER         NOT NULL,
    FIDO       TIMESTAMP       NOT NULL
                               DEFAULT CURRENT_TIME,
    FUSER      VARCHAR( 70 )   DEFAULT NULL,
    CONSTRAINT TIPUSOK_CSOPORT FOREIGN KEY ( FCSOPORT ) REFERENCES TCSOPORTOK ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE 
);
CREATE UNIQUE INDEX idx_TIPUSOK_NEV ON TTIPUSOK ( 
    FNEV,
    FCSOPORT 
);
CREATE INDEX idx_TIPUSOK_CSOPORT ON TTIPUSOK ( 
    FCSOPORT 
);
INSERT INTO TTIPUSOK VALUES ( 
    1,
    'Alap. típus',
    'Alapértelmezett típus',
    1,
    CURRENT_TIME,
    NULL 
);

CREATE TABLE TTORZS ( 
    FRAKTKOD    VARCHAR( 70 )     NOT NULL,
    FRENDKOD    VARCHAR( 70 )     NOT NULL,
    FNEV        VARCHAR( 100 )    NOT NULL,
    FBESZALLITO INTEGER           NOT NULL,
    FGYARTO     INTEGER           NOT NULL,
    FCSOPTIP    INTEGER           NOT NULL,
    FAFATIPUS   INTEGER           NOT NULL,
    FDEFBESZAR  DECIMAL( 10, 2 )  DEFAULT NULL,
    FDEFELADAR  DECIMAL( 10, 2 )  DEFAULT NULL,
    FMINKESZLET DECIMAL( 10, 2 )  DEFAULT NULL,
    FBESZIDO    DECIMAL( 10, 2 )  DEFAULT NULL,
    FEGYSEG     VARCHAR( 20 )     DEFAULT NULL,
    FITJ        VARCHAR( 70 )     DEFAULT NULL,
    FLEIRAS     VARCHAR( 255 )    DEFAULT NULL,
    FIMAGE      LONGBLOB,
    FIDO        TIMESTAMP         NOT NULL
                                  DEFAULT CURRENT_TIME,
    FUSER       VARCHAR( 70 )     DEFAULT NULL,
    PRIMARY KEY ( FRAKTKOD ),
    CONSTRAINT TORZS_AFA FOREIGN KEY ( FAFATIPUS ) REFERENCES TAFATIPUSOK ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE,
    CONSTRAINT TORZS_BESZALL FOREIGN KEY ( FBESZALLITO ) REFERENCES TPARTNEREK ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE,
    CONSTRAINT TORZS_CSOPTIP FOREIGN KEY ( FCSOPTIP ) REFERENCES TTIPUSOK ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE,
    CONSTRAINT TORZS_GYARTO FOREIGN KEY ( FGYARTO ) REFERENCES TPARTNEREK ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE 
);

CREATE TABLE TTULAJDONSAGOK ( 
    FAZONOSITO INTEGER         PRIMARY KEY AUTOINCREMENT
                               NOT NULL,
    FNEV       VARCHAR( 70 )   NOT NULL,
    FTIPUS     INTEGER         NOT NULL,
    FLEIRAS    VARCHAR( 255 )  DEFAULT NULL,
    FIDO       TIMESTAMP       NOT NULL
                               DEFAULT CURRENT_TIME,
    FUSER      VARCHAR( 70 )   DEFAULT NULL 
);
CREATE UNIQUE INDEX idx_NEV_TULAJDONSAGOK ON TTULAJDONSAGOK ( 
    FNEV 
);

CREATE TABLE TTULAJERTEK ( 
    FAZONOSITO   INTEGER           PRIMARY KEY AUTOINCREMENT
                                   NOT NULL,
    FRAKTKOD     VARCHAR( 70 )     NOT NULL,
    FTULAJDONSAG INTEGER           NOT NULL,
    FSTRING      VARCHAR( 255 )    DEFAULT NULL,
    FDOUBLE      DECIMAL( 10, 2 )  DEFAULT NULL,
    FIDO         TIMESTAMP         NOT NULL
                                   DEFAULT CURRENT_TIME,
    FUSER        VARCHAR( 70 )     DEFAULT NULL,
    CONSTRAINT TULAJERTEK_RAKTKOD FOREIGN KEY ( FRAKTKOD ) REFERENCES TTORZS ( FRAKTKOD ) ON DELETE RESTRICT ON UPDATE CASCADE,
    CONSTRAINT TULAJERTEK_TULAJD FOREIGN KEY ( FTULAJDONSAG ) REFERENCES TTULAJDONSAGOK ( FAZONOSITO ) ON DELETE RESTRICT ON UPDATE CASCADE 
);

CREATE TABLE TUSERS ( 
    FUSERID   VARCHAR( 70 )  NOT NULL,
    FPASSWORD VARCHAR( 70 )  NOT NULL,
    FTIPUS    VARCHAR( 70 )  NOT NULL,
    FIDO      TIMESTAMP      NOT NULL
                             DEFAULT CURRENT_TIME,
    FUSER     VARCHAR( 70 )  DEFAULT NULL,
    PRIMARY KEY ( FUSERID ) 
);
INSERT INTO TUSERS VALUES ( 
    'default',
    'd',
    'AdminDocumentsMaintenanceQueryStorage',
    CURRENT_TIME,
    'default' 
);

